@@ -9,6 +9,7 @@
 #include "EditProfileDialog.h"
 
 // Qt
+#include <QColor>
 #include <QDialog>
 #include <QDialogButtonBox>
 #include <QFileDialog>
@@ -17,15 +18,16 @@
 #include <QMenu>
 #include <QPushButton>
 #include <QRegularExpressionValidator>
+#include <QSlider>
 #include <QStandardItem>
 #include <QStandardPaths>
 #include <QStringListModel>
-#include <QTextCodec>
 #include <QTimer>
 #include <QUrl>
 
 // KDE
 #include <KCodecAction>
+#include <KColorButton>
 #include <KIconDialog>
 #include <KLocalizedString>
 #include <KWindowSystem>
@@ -1748,6 +1750,13 @@ void EditProfileDialog::setupScrollingPage(const Profile::Ptr &profile)
     _scrollingUi->markerSizeWidget->setValue(profile->property<double>(Profile::MarkerSize));
     connect(_scrollingUi->markerSizeWidget, &QDoubleSpinBox::valueChanged, this, &Konsole::EditProfileDialog::toggleScrollbarMarkerSize);
 
+    // setup search highlighter color button
+    _scrollingUi->searchHighligheterColorButton->setColor(profile->property<QColor>(Profile::SearchLineColor));
+    connect(_scrollingUi->searchHighligheterColorButton, &KColorButton::changed, this, &Konsole::EditProfileDialog::toggleScrollbarSearchLineColor);
+
+    // setup search highlighter opacity widget
+    _scrollingUi->labelSearchHighlighterOpacitySlider->setValue(profile->property<int>(Profile::SearchLineOpacity));
+    connect(_scrollingUi->labelSearchHighlighterOpacitySlider, &QSlider::valueChanged, this, &Konsole::EditProfileDialog::toggleScrollbarSearchLineOpacity);
     // signals and slots
     connect(_scrollingUi->historySizeWidget, &Konsole::HistorySizeWidget::historySizeChanged, this, &Konsole::EditProfileDialog::historySizeChanged);
 }
@@ -1792,6 +1801,14 @@ void EditProfileDialog::toggleScrollbarMarkerSize(double pSize)
     updateTempProfileProperty(Profile::MarkerSize, pSize);
 }
 
+void EditProfileDialog::toggleScrollbarSearchLineColor(QColor color) {
+    updateTempProfileProperty(Profile::SearchLineColor, color);
+}
+
+void EditProfileDialog::toggleScrollbarSearchLineOpacity(int opacity) {
+    updateTempProfileProperty(Profile::SearchLineOpacity, opacity);
+}
+
 void EditProfileDialog::setupMousePage(const Profile::Ptr &profile)
 {
     _mouseUi->underlineLinksButton->setChecked(profile->property<bool>(Profile::UnderlineLinksEnabled));
@@ -1996,11 +2013,11 @@ void EditProfileDialog::setupAdvancedPage(const Profile::Ptr &profile)
     _advancedUi->selectEncodingButton->setMenu(codecAction->menu());
 
     connect(codecAction, &KCodecAction::codecNameTriggered, this, [this](const QByteArray &codecName) {
-        setDefaultCodec(QTextCodec::codecForName(codecName));
+        setDefaultCodec(codecName);
     });
 
     connect(codecAction, &KCodecAction::defaultItemTriggered, this, [this] {
-        setDefaultCodec(QTextCodec::codecForLocale());
+        setDefaultCodec(QStringConverter::nameForEncoding(QStringConverter::System));
     });
 
     _advancedUi->selectEncodingButton->setText(profile->defaultEncoding());
@@ -2051,9 +2068,9 @@ int EditProfileDialog::maxSpinBoxWidth(const KPluralHandlingSpinBox *spinBox, co
     return spinBoxSize.width();
 }
 
-void EditProfileDialog::setDefaultCodec(QTextCodec *codec)
+void EditProfileDialog::setDefaultCodec(const QByteArray &codec)
 {
-    QString name = QString::fromLocal8Bit(codec->name());
+    QString name = QString::fromLocal8Bit(codec);
 
     updateTempProfileProperty(Profile::DefaultEncoding, name);
     _advancedUi->selectEncodingButton->setText(name);
